==> nextcloud-11.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/lv.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Izmaiņas",
    "Error loading activities" : "Kļūda ielādējot izmaiņas",
    "No activities" : "Nav izmaiņu",
    "Load more activities" : "Ielādēt vairāk izmaiņas",
    "This stream will show events like additions, changes & shares" : "Šajā straumē tiks parādītas koplietošanas, dalīšanās un citi notikumi.",
    "There are no events for this filter" : "Šim filtram nav notikumu",
    "Today" : "Šodien",
    "Yesterday" : "Vakar",
    "Activity" : "Izmaiņas",
    "Personal activity feed for %s" : "%s personīgā izmaiņu plūsma ",
    "Your feed URL is invalid" : "Jūsu plūsmas URL nav derīgs.",
    "Your settings have been updated." : "Jūsu uzstādījumi ir atjaunoti.",
    "Mail" : "E-pasts",
    "Stream" : "Datu straume",
    "\"remote user\"" : "\"attālināts lietotājs\"",
    "Activity notification" : "Brīdinājumi par izmaiņām",
    ", " : ",",
    "%s and %s" : "%s un %s",
    "Hello %s," : "Sveicināti %s,",
    "You are receiving this email because the following things happened at %s" : "Jūs saņemat šo e-pastu, jo %s notika sekojošais",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["*","* un vēl %n","* un vēl %n"],
    "Notify about your own actions via email" : "Paziņot par savām darbībām, izmantojot e-pastu",
    "You need to set up your email address before you can receive notification emails." : "Vispirms profilam ir nepieciešams uzstādīt e-pasta adresi, lai pa to saņemtu paziņojumus.",
    "Send emails:" : "E-pastus sūtīt:",
    "Hourly" : "Ik stundu",
    "Daily" : "Katru dienu",
    "Weekly" : "Katru nedēļu",
    "Activity feed" : "Izmaiņu plūsma",
    "Enable RSS feed" : "Ieslēgt RSS plūsmu",
    "No activity yet" : "Vēl nav aktivitāšu",
    "No more events to load" : "Nav vairs notikumu, ko ielādēt",
    "Files" : "Datnes"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/lv.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Izmaiņas",
    "An error occurred while loading activities" : "Radās kļūda, ielādējot darbības",
    "No activity yet" : "Vēl nav aktivitāšu",
    "Load more activities" : "Ielādēt vairāk izmaiņas",
    "Copied!" : "Nokopēts!",
    "Not supported!" : "Nav atbalstīts!",
    "Press ⌘-C to copy." : "Spied ⌘-C lai kopētu.",
    "Press Ctrl-C to copy." : "Spied Ctrl-C lai kopētu.",
    "{name} (invisible)" : "{name} (neredzams)",
    "{name} (restricted)" : "{name} (ierobežots)",
    "in {path}" : "{path}",
    "This stream will show events like additions, changes & shares" : "Šajā straumē tiks parādītas koplietošanas, dalīšanās un citi notikumi.",
    "There are no events for this filter" : "Šim filtram nav notikumu",
    "Today" : "Šodien",
    "Yesterday" : "Vakar",
    "Personal activity feed for %s" : "%s personīgā izmaiņu plūsma ",
    "Your feed URL is invalid" : "Jūsu plūsmas URL nav derīgs.",
    "Your settings have been updated." : "Jūsu uzstādījumi ir atjaunoti.",
    "Settings have been updated." : "Iestādījumi ir atjaunoti.",
    "Mail" : "E-pasts",
    "Stream" : "Datu straume",
    "All activities" : "Visas darbības",
    "By others" : "Citi",
    "By you" : "Ar jums",
    "\"remote user\"" : "\"attālināts lietotājs\"",
    "Hello %s," : "Sveicināti %s,",
    "There was some activity at %s" : "Tur bija kaut kādas aktivitātes %s",
    "Activity notification" : "Brīdinājumi par izmaiņām",
    ", " : ",",
    "%s and %s" : "%s un %s",
    "Activity" : "Izmaiņas",
    "Activity feed" : "Izmaiņu plūsma",
    "List your own actions in the stream" : "Attēlot savu darbību plūsmā",
    "Notify about your own actions via email" : "Paziņot par savām darbībām, izmantojot e-pastu",
    "You need to set up your email address before you can receive notification emails." : "Vispirms profilam ir nepieciešams uzstādīt e-pasta adresi, lai pa to saņemtu paziņojumus.",
    "Send emails:" : "E-pastus sūtīt:",
    "Hourly" : "Ik stundu",
    "Daily" : "Katru dienu",
    "Weekly" : "Katru nedēļu",
    "Settings" : "Iestatījumi",
    "Enable RSS feed" : "Ieslēgt RSS plūsmu",
    "No more events to load" : "Nav vairs notikumu, ko ielādēt",
    "Files" : "Datnes"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
